@@ -30,7 +30,6 @@
 #include "linalg.h"
 #include "gen_covar.h"
 #include "rhelp.h"
-#include "bessel_k.h"
 
 /* #define THRESH 0.5 */
 
@@ -407,7 +406,7 @@ unsigned int n;
 double **M, **Mi, **Mutil;
 {
   unsigned int i,j;
-  int info;
+  /* int info; */
   
   /* first make Mi the identity */	
   id(Mi, n);
@@ -416,7 +415,7 @@ double **M, **Mi, **Mutil;
   for(i=0; i<n; i++) for(j=0; j<=i; j++) Mutil[i][j] = M[i][j];
   
   /* create inverse of M in Mi, and return choleski in Mutil */
-  info = linalg_dposv(n, Mutil, Mi);
+  /* info = */ linalg_dposv(n, Mutil, Mi);
 }
 
 
@@ -437,7 +436,7 @@ void inverse_lu(M, Mi, Mutil, n)
 unsigned int n;
 double **M, **Mi, **Mutil;
 {
-  int info;
+  /* int info; */
   
   /* first make Mi the identity */	
   /* and make a (full) copy of M */
@@ -446,7 +445,7 @@ double **M, **Mi, **Mutil;
   /* not sure that a full copy is necessary actually */
   
   /* then use LAPACK */
-  info = linalg_dgesv(n, Mutil, Mi);
+  /* info =*/ linalg_dgesv(n, Mutil, Mi);
 }
 
 
@@ -487,11 +486,10 @@ double *b, *x;
  * K[n][m], DIST[n][m]
  */
 
-void matern_dist_to_K(K, DIST, d, nu, bk, nb, nug, m, n)
+void matern_dist_to_K(K, DIST, d, nu, bk, nug, m, n)
 unsigned int m,n;
 double **K, **DIST, *bk;
 double d, nug, nu;
-long nb;
 {
   int i,j;
   double c;
@@ -521,8 +519,7 @@ long nb;
 	    K[i][j] = nu*(log(DIST[i][j])-log(d));
 	    
 	    /* bessel calculation */
-	    /* K[i][j] += log(bessel_k(DIST[i][j]/d, nu, 1.0)); */
-	    K[i][j] += log_bessel_k(DIST[i][j]/d, nu, 1.0, bk, nb);
+	    K[i][j] += log(bessel_k_ex(DIST[i][j]/d, nu, 1.0, bk));
 
 	    /* go from log space to regular space */
 	    K[i][j] = exp(K[i][j]-c);
@@ -550,11 +547,10 @@ long nb;
  * K[n][n], DIST[n][n]
  */
 
-void matern_dist_to_K_symm(K, DIST, d, nu, bk, nb, nug, n)
+void matern_dist_to_K_symm(K, DIST, d, nu, bk, nug, n)
 unsigned int n;
 double **K, **DIST, *bk;
 double d, nug, nu;
-long nb;
 {
   int i,j;
   double c;
@@ -586,8 +582,7 @@ long nb;
       K[i][j] = nu*(log(DIST[i][j])-log(d));
       
       /* bessel calculation */
-      /* K[i][j] += log(bessel_k(DIST[i][j]/d, nu, 1.0)); */
-      K[i][j] += log_bessel_k(DIST[i][j]/d, nu, 1.0, bk, nb);
+      K[i][j] += log(bessel_k_ex(DIST[i][j]/d, nu, 1.0, bk));
 
       /* go from log space to regular space */
       K[i][j] = exp(K[i][j]-c);
