@@ -24,7 +24,6 @@
 
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include "rand_draws.h"
 #include "rand_pdf.h"
@@ -89,7 +88,7 @@ double ss2;
 
   /* Note that now K is passed with jitter included.
      This was previously removed in the predict_full fn. */
-  /* printf("zp: "); printVector(zpjitter,5,stdout, HUMAN); */
+  /* printf("zp: "); printVector(zpjitter,5,mystdout, HUMAN); */
   
   /* for each point at which we want a prediction */
   for(i=0; i<n1; i++) {
@@ -337,7 +336,7 @@ double tau2;
   /*double ZmFb[n1]; double KpFWF[n1][n1]; int p[n1]; */
   double *ZmFb;
   double **KpFWF;
-  int info;
+  /* int info; */
   
   /* ZmFb = Zdat - F * beta; first, copy Z */
   /* THIS IS Z-FB AGAIN, definately should move this up one level */
@@ -361,7 +360,7 @@ double tau2;
   /* KpFWFi = inv(K + FWF') */
   id(KpFWFi, n1);
   /* compute inverse, replacing KpFWF with its cholesky decomposition */
-  info = linalg_dgesv(n1, KpFWF, KpFWFi);
+  /* info = */ linalg_dgesv(n1, KpFWF, KpFWFi);
   delete_matrix(KpFWF);
 }
 
@@ -550,7 +549,7 @@ void expected_improv(n, nn, improv, Zmin, zzm, zzs2)
   /* calculate best minimum so far */
   /* fmin = min(Z, n, &which);*/
   fmin = Zmin;
-  /* myprintf(stderr, "Zmin = %g, min(zzm) = %g\n", Zmin, min(zzm, nn, &which)); */
+  /* myprintf(mystderr, "Zmin = %g, min(zzm) = %g\n", Zmin, min(zzm, nn, &which)); */
 
   for(i=0; i<nn; i++) {
 
@@ -637,7 +636,7 @@ unsigned int* GetImprovRank(int R, int nn, double **Imat_in, int g,
   unsigned int j, i, k, /* m,*/ maxj;
   double *colmean, *maxcol;
   double **Imat;
-  double maxmean;
+  /* double maxmean; */
   unsigned int *pntind;
 
   /* allocate the ranking vector */
@@ -662,7 +661,7 @@ unsigned int* GetImprovRank(int R, int nn, double **Imat_in, int g,
   
   /* which column yields the maximum improvement */
   maxj = 0;
-  maxmean = max(colmean, nn, &maxj);
+  /* maxmean = */ max(colmean, nn, &maxj);
 
   /* the maxj-th input is ranked first */
   pntind[maxj] = 1;
@@ -688,7 +687,7 @@ unsigned int* GetImprovRank(int R, int nn, double **Imat_in, int g,
     wmean_of_columns(colmean, Imat, R, nn, w);
 
     /* which column yeilds the maximum improvement */
-    maxmean = max(colmean, nn, &maxj);
+    /* maxmean =*/ max(colmean, nn, &maxj);
 
     /* the maxj-th column is ranked k+1st */
     /* make sure that pntind[maxj] is not already filled */
@@ -778,7 +777,7 @@ void move_avg(int nn, double* XX, double *YY, int n, double* X,
     /* record the (normalized) weighted average in the window */
     sumW = sumv(&(w[l]), q);
     YY[i] = vmult(&(w[l]), &(Yo[l]), q)/sumW;
-    /*printf("YY = "); printVector(YY, nn, stdout, HUMAN);*/
+    /*printf("YY = "); printVector(YY, nn, mystdout, HUMAN);*/
   }
   
   /* clean up */
