@@ -30,7 +30,6 @@
 #include "rhelp.h"
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <Rmath.h> 
 #include "randomkit.h"
@@ -194,7 +193,7 @@ double runi(void *state)
     unsigned long rv;
     assert(state);
     rv = rk_random((rk_state*) state);
-    /* myprintf(stderr, "(%d)",  ((int)(10000000 * (((double) rv)/RK_MAX))));
+    /* myprintf(mystderr, "(%d)",  ((int)(10000000 * (((double) rv)/RK_MAX))));
        if(((int)(10000000 * (((double) rv)/RK_MAX))) == 7294478) assert(0); */
     return ((double) rv) / RK_MAX;
   }
@@ -322,10 +321,10 @@ void *state;
 {
     /*double x_temp[n];*/
     double *x_temp;
-    int i, j, info;
+    int i, j /*, info*/;
 
     /* get the choleski decomposition */
-    info = linalg_dpotrf(n, cov);
+    /* info =*/ linalg_dpotrf(n, cov);
 
     /* get CASES draws from a multivariate normal */
     x_temp = (double*) malloc(sizeof(double) * n);
